/*
 * Stili per la cartella della modulistica 
 */

table.modulisticaListing {
	width: 97%;
}

#content .modulisticaListing a[href^="http:"] {
	background-image: none;
	padding: 0px;
}

table.modulisticaListing,
table.modulisticaListing td,
table.modulisticaListing th {
	border-color: #999;
}

table.modulisticaListing th.modulisticaDocument {
	background: none repeat scroll 0 0 #EFEFEF;
    border-bottom: 1px solid #999999;
    border-right: 1px solid #999999;
    border-top: 1px solid #999999;
    font-weight: normal;
    padding: 0.25em 0.5em;
    text-transform: none;
}

table.modulisticaListing tr.headingModuli th {
	color: black;
}